@@ -5,7 +5,7 @@ use strict;
 use warnings; no warnings qw(void once uninitialized numeric redefine);
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.037_02';
+our $VERSION   = '0.037_03';
 our @EXPORT_OK = qw< mkopt mkopt_hash _croak >;
 
 sub _croak ($;@) { require Carp; my $fmt = shift; @_ = sprintf($fmt, @_); goto \&Carp::croak }
@@ -71,12 +71,15 @@ sub _exporter_merge_opts
 	my $class = shift;
 	my ($tag_opts, $global_opts, @stuff) = @_;
 	
+	$tag_opts = {} unless ref($tag_opts) eq q(HASH);
 	_croak('Cannot provide an -as option for tags')
 		if exists $tag_opts->{-as};
 	
 	my $optlist = mkopt(\@stuff);
 	for my $export (@$optlist)
 	{
+		next if defined($export->[1]) && ref($export->[1]) ne q(HASH);
+		
 		my %sub_opts = ( %{ $export->[1] or {} }, %$tag_opts );
 		$sub_opts{-prefix} = sprintf('%s%s', $tag_opts->{-prefix}, $export->[1]{-prefix})
 			if exists($export->[1]{-prefix}) && exists($tag_opts->{-prefix});
@@ -462,7 +465,7 @@ throwing an exception or printing a warning.
 
 The default implementation does nothing interesting.
 
-item C<< _exporter_merge_opts($tag_opts, $globals, @exports) >>
+=item C<< _exporter_merge_opts($tag_opts, $globals, @exports) >>
 
 Called to merge options which have been provided for a tag into the
 options provided for the exports that the tag expanded to.
